@@ -1,7 +1,7 @@
 context("PipeOpFixFactors")
 
 test_that("PipeOpFixFactors", {
-  task = mlr_tasks$get("boston_housing")
+  task = mlr_tasks$get("boston_housing_classic")
 
   chaslevels = task$levels()$chas
   townlevels = task$levels()$town
